[libvirt] [PATCH] LXC: s/chroot/chdir in lxcContainerPivotRoot()

Richard Weinberger richard at nod.at
Fri Jun 14 06:57:55 UTC 2013


...fixes a trivial copy&paste error.

Signed-off-by: Richard Weinberger <richard at nod.at>
---
 src/lxc/lxc_container.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/src/lxc/lxc_container.c b/src/lxc/lxc_container.c
index 7531fea..c4056c3 100644
--- a/src/lxc/lxc_container.c
+++ b/src/lxc/lxc_container.c
@@ -653,11 +653,11 @@ static int lxcContainerPivotRoot(virDomainFSDefPtr root)
         }
     }
 
     /* Now we chroot into the tmpfs, then pivot into the
      * root->src bind-mounted onto '/new' */
     if (chdir(newroot) < 0) {
         virReportSystemError(errno,
-                             _("Failed to chroot into %s"), newroot);
+                             _("Failed to chdir into %s"), newroot);
         goto err;
     }
 
@@ -653,11 +653,11 @@ static int lxcContainerPivotRoot(virDomainFSDefPtr root)
     }
 
-    /* Now we chroot into the tmpfs, then pivot into the
+    /* Now we chdir into the tmpfs, then pivot into the
      * root->src bind-mounted onto '/new' */
     if (chdir(newroot) < 0) {
-- 
1.8.1.4




More information about the libvir-list mailing list